@@ -13,6 +13,8 @@ then
 	echo "fs true" >> $CFG_FILE
 	echo "game_genie false" >> $CFG_FILE
 	echo "tv_blur false" >> $CFG_FILE
+	echo "rom2_path notset" >> $CFG_FILE
+	echo "rom_path_active 1" >> $CFG_FILE
 fi
 # Set missing values
 grep ^exec_path $CFG_FILE >/dev/null || echo "exec_path /usr/bin" >> $CFG_FILE
@@ -23,6 +25,8 @@ grep ^bpp $CFG_FILE >/dev/null || echo "bpp 16" >> $CFG_FILE
 grep ^fs $CFG_FILE >/dev/null || echo "fs true" >> $CFG_FILE
 grep ^game_genie $CFG_FILE >/dev/null || echo "game_genie false" >> $CFG_FILE
 grep ^tv_blur $CFG_FILE >/dev/null || echo "tv_blur false" >> $CFG_FILE
+grep ^rom2_path $CFG_FILE >/dev/null || echo "rom2_path notset" >> $CFG_FILE
+grep ^rom_path_active $CFG_FILE >/dev/null || echo "rom_path_active 1" >> $CFG_FILE
  
 cd /opt/fceu-gui/
 python fceu-gui.py
